"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.complete_payment_setup_psp_request import CompletePaymentSetupPspRequest
from eis.customers.model.complete_payment_setup_response_class import CompletePaymentSetupResponseClass
from eis.customers.model.initiate_payment_setup_response_class import InitiatePaymentSetupResponseClass


class PaymentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.complete_payment_setup_endpoint = _Endpoint(
            settings={
                'response_type': (CompletePaymentSetupResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/payment_setup/complete',
                'operation_id': 'complete_payment_setup',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'complete_payment_setup_psp_request',
                    'authorization',
                ],
                'required': [
                    'customer_code',
                    'complete_payment_setup_psp_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'complete_payment_setup_psp_request':
                        (CompletePaymentSetupPspRequest,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'complete_payment_setup_psp_request': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.initiate_payment_setup_endpoint = _Endpoint(
            settings={
                'response_type': (InitiatePaymentSetupResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/payment_setup/initiate',
                'operation_id': 'initiate_payment_setup',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'authorization',
                ],
                'required': [
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def complete_payment_setup(
        self,
        customer_code,
        complete_payment_setup_psp_request,
        **kwargs
    ):
        """Request payment setup complete  # noqa: E501

        Request to complete a payment change by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.complete_payment_setup(customer_code, complete_payment_setup_psp_request, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            complete_payment_setup_psp_request (CompletePaymentSetupPspRequest):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CompletePaymentSetupResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['complete_payment_setup_psp_request'] = \
            complete_payment_setup_psp_request
        return self.complete_payment_setup_endpoint.call_with_http_info(**kwargs)

    def initiate_payment_setup(
        self,
        customer_code,
        **kwargs
    ):
        """Request payment setup initiation  # noqa: E501

        Request to initiate a payment change by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.initiate_payment_setup(customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            InitiatePaymentSetupResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        return self.initiate_payment_setup_endpoint.call_with_http_info(**kwargs)




"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.claims_api import ClaimsApi  # noqa: E501


class TestClaimsApi(unittest.TestCase):
    """ClaimsApi unit test stubs"""

    def setUp(self):
        self.api = ClaimsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer_claim(self):
        """Test case for create_customer_claim

        Create a new claim  # noqa: E501
        """
        pass

    def test_get_customer_claim(self):
        """Test case for get_customer_claim

        Get claim  # noqa: E501
        """
        pass

    def test_list_customer_claims(self):
        """Test case for list_customer_claims

        List claims  # noqa: E501
        """
        pass

    def test_update_customer_claim(self):
        """Test case for update_customer_claim

        Update claim  # noqa: E501
        """
        pass

    def test_upload_customer_claim_documents(self):
        """Test case for upload_customer_claim_documents

        Upload claim documents  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.create_customer_request_dto import CreateCustomerRequestDto
from eis.customers.model.create_customer_response_class import CreateCustomerResponseClass
from eis.customers.model.invite_by_customer_request_dto import InviteByCustomerRequestDto
from eis.customers.model.invite_by_customer_response_class import InviteByCustomerResponseClass
from eis.customers.model.invite_by_tenant_request_dto import InviteByTenantRequestDto
from eis.customers.model.invite_by_tenant_response_class import InviteByTenantResponseClass
from eis.customers.model.verify_customer_invite_response_class import VerifyCustomerInviteResponseClass


class InvitesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_customer_endpoint = _Endpoint(
            settings={
                'response_type': (CreateCustomerResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/create',
                'operation_id': 'create_customer',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_customer_request_dto',
                ],
                'required': [
                    'create_customer_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_customer_request_dto':
                        (CreateCustomerRequestDto,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_customer_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.invite_by_customer_endpoint = _Endpoint(
            settings={
                'response_type': (InviteByCustomerResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/invites/by-customer',
                'operation_id': 'invite_by_customer',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'invite_by_customer_request_dto',
                    'authorization',
                ],
                'required': [
                    'invite_by_customer_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'invite_by_customer_request_dto':
                        (InviteByCustomerRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'invite_by_customer_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.invite_by_tenant_endpoint = _Endpoint(
            settings={
                'response_type': (InviteByTenantResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/invites/by-tenant',
                'operation_id': 'invite_by_tenant',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'invite_by_tenant_request_dto',
                    'authorization',
                ],
                'required': [
                    'invite_by_tenant_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'invite_by_tenant_request_dto':
                        (InviteByTenantRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'invite_by_tenant_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.verify_invite_endpoint = _Endpoint(
            settings={
                'response_type': (VerifyCustomerInviteResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/invites/verify',
                'operation_id': 'verify_invite',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'invite_token',
                ],
                'required': [
                    'invite_token',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'invite_token':
                        (str,),
                },
                'attribute_map': {
                    'invite_token': 'inviteToken',
                },
                'location_map': {
                    'invite_token': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def create_customer(
        self,
        create_customer_request_dto,
        **kwargs
    ):
        """Register a customer after invite  # noqa: E501

        Register a customer using the invite token sent to customer's email address. Customer can set a new password for his account created during booking a policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_customer(create_customer_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            create_customer_request_dto (CreateCustomerRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateCustomerResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['create_customer_request_dto'] = \
            create_customer_request_dto
        return self.create_customer_endpoint.call_with_http_info(**kwargs)

    def invite_by_customer(
        self,
        invite_by_customer_request_dto,
        **kwargs
    ):
        """Invite a customer by self  # noqa: E501

        Send a customer an invite via email to register. An account should have been created before inviting the customer. To invite users without accounts and policies is not yet supported.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.invite_by_customer(invite_by_customer_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            invite_by_customer_request_dto (InviteByCustomerRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the Emil Insurance Suite's Auth login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            InviteByCustomerResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['invite_by_customer_request_dto'] = \
            invite_by_customer_request_dto
        return self.invite_by_customer_endpoint.call_with_http_info(**kwargs)

    def invite_by_tenant(
        self,
        invite_by_tenant_request_dto,
        **kwargs
    ):
        """Invite a customer by tenant  # noqa: E501

        Send a customer an invite via email to register. An account should have been created before inviting the customer. To invite users without accounts and policies is not yet supported.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.invite_by_tenant(invite_by_tenant_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            invite_by_tenant_request_dto (InviteByTenantRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the Emil Insurance Suite's Auth login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            InviteByTenantResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['invite_by_tenant_request_dto'] = \
            invite_by_tenant_request_dto
        return self.invite_by_tenant_endpoint.call_with_http_info(**kwargs)

    def verify_invite(
        self,
        invite_token,
        **kwargs
    ):
        """Verify customer's invite token  # noqa: E501

        Verify the invite sent to the customer via email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.verify_invite(invite_token, async_req=True)
        >>> result = thread.get()

        Args:
            invite_token (str): Invite token sent to the customer

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            VerifyCustomerInviteResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['invite_token'] = \
            invite_token
        return self.verify_invite_endpoint.call_with_http_info(**kwargs)




"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forgot_password(self):
        """Test case for forgot_password

        Forgot password by customer  # noqa: E501
        """
        pass

    def test_initiate_auth(self):
        """Test case for initiate_auth

        Initiate auth by customer  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refresh token by customer  # noqa: E501
        """
        pass

    def test_reset_password(self):
        """Test case for reset_password

        Change password by customer  # noqa: E501
        """
        pass

    def test_respond_to_auth_challenge(self):
        """Test case for respond_to_auth_challenge

        Respond to auth challenge  # noqa: E501
        """
        pass

    def test_verify_reset_password_token(self):
        """Test case for verify_reset_password_token

        Verify a reset password token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.customers_api import CustomersApi  # noqa: E501


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self):
        self.api = CustomersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer(self):
        """Test case for get_customer

        Get customer details  # noqa: E501
        """
        pass

    def test_list_customers(self):
        """Test case for list_customers

        Get customers list  # noqa: E501
        """
        pass

    def test_update_customer(self):
        """Test case for update_customer

        Update customer details  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_account_request_dto import CreateAccountRequestDto
from eis.customers.model.create_payment_method_request_dto import CreatePaymentMethodRequestDto
from eis.customers.model.create_policy_request_dto import CreatePolicyRequestDto
from eis.customers.model.invoice_class import InvoiceClass
from eis.customers.model.lead_bank_account_class import LeadBankAccountClass
from eis.customers.model.premium_override_request_class import PremiumOverrideRequestClass
from eis.customers.model.uploaded_document_dto import UploadedDocumentDto
globals()['CreateAccountRequestDto'] = CreateAccountRequestDto
globals()['CreatePaymentMethodRequestDto'] = CreatePaymentMethodRequestDto
globals()['CreatePolicyRequestDto'] = CreatePolicyRequestDto
globals()['InvoiceClass'] = InvoiceClass
globals()['LeadBankAccountClass'] = LeadBankAccountClass
globals()['PremiumOverrideRequestClass'] = PremiumOverrideRequestClass
globals()['UploadedDocumentDto'] = UploadedDocumentDto
from eis.customers.model.lead_class import LeadClass


class TestLeadClass(unittest.TestCase):
    """LeadClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLeadClass(self):
        """Test LeadClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = LeadClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.forgot_password_request_dto import ForgotPasswordRequestDto
from eis.customers.model.initiate_auth_request_dto import InitiateAuthRequestDto
from eis.customers.model.initiate_auth_response_class import InitiateAuthResponseClass
from eis.customers.model.refresh_token_dto import RefreshTokenDto
from eis.customers.model.reset_password_by_customer_request_dto import ResetPasswordByCustomerRequestDto
from eis.customers.model.respond_to_auth_challenge_class import RespondToAuthChallengeClass
from eis.customers.model.respond_to_auth_challenge_request_dto import RespondToAuthChallengeRequestDto


class AuthenticationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.forgot_password_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/customers/forgot-password',
                'operation_id': 'forgot_password',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'forgot_password_request_dto',
                ],
                'required': [
                    'forgot_password_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'forgot_password_request_dto':
                        (ForgotPasswordRequestDto,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'forgot_password_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.initiate_auth_endpoint = _Endpoint(
            settings={
                'response_type': (InitiateAuthResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/auth/initiate',
                'operation_id': 'initiate_auth',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'initiate_auth_request_dto',
                ],
                'required': [
                    'initiate_auth_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'initiate_auth_request_dto':
                        (InitiateAuthRequestDto,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'initiate_auth_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.refresh_token_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/customers/refresh-token',
                'operation_id': 'refresh_token',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'refresh_token_dto',
                    'cookie',
                ],
                'required': [
                    'refresh_token_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'refresh_token_dto':
                        (RefreshTokenDto,),
                    'cookie':
                        (str,),
                },
                'attribute_map': {
                    'cookie': 'Cookie',
                },
                'location_map': {
                    'refresh_token_dto': 'body',
                    'cookie': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.reset_password_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/customers/reset-password',
                'operation_id': 'reset_password',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'reset_password_by_customer_request_dto',
                ],
                'required': [
                    'reset_password_by_customer_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reset_password_by_customer_request_dto':
                        (ResetPasswordByCustomerRequestDto,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'reset_password_by_customer_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.respond_to_auth_challenge_endpoint = _Endpoint(
            settings={
                'response_type': (RespondToAuthChallengeClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/auth/respond',
                'operation_id': 'respond_to_auth_challenge',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'respond_to_auth_challenge_request_dto',
                ],
                'required': [
                    'respond_to_auth_challenge_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'respond_to_auth_challenge_request_dto':
                        (RespondToAuthChallengeRequestDto,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'respond_to_auth_challenge_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.verify_reset_password_token_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/customers/verify-reset-password',
                'operation_id': 'verify_reset_password_token',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reset_token',
                ],
                'required': [
                    'reset_token',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reset_token':
                        (str,),
                },
                'attribute_map': {
                    'reset_token': 'resetToken',
                },
                'location_map': {
                    'reset_token': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )

    def forgot_password(
        self,
        forgot_password_request_dto,
        **kwargs
    ):
        """Forgot password by customer  # noqa: E501

        Send a customer a reset-password token via email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.forgot_password(forgot_password_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            forgot_password_request_dto (ForgotPasswordRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['forgot_password_request_dto'] = \
            forgot_password_request_dto
        return self.forgot_password_endpoint.call_with_http_info(**kwargs)

    def initiate_auth(
        self,
        initiate_auth_request_dto,
        **kwargs
    ):
        """Initiate auth by customer  # noqa: E501

        Start auth process to get new access token, refresh token after successful login.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.initiate_auth(initiate_auth_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            initiate_auth_request_dto (InitiateAuthRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            InitiateAuthResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['initiate_auth_request_dto'] = \
            initiate_auth_request_dto
        return self.initiate_auth_endpoint.call_with_http_info(**kwargs)

    def refresh_token(
        self,
        refresh_token_dto,
        **kwargs
    ):
        """Refresh token by customer  # noqa: E501

        Get new access token, new refresh token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.refresh_token(refresh_token_dto, async_req=True)
        >>> result = thread.get()

        Args:
            refresh_token_dto (RefreshTokenDto):

        Keyword Args:
            cookie (str): HTTP only cookie that was sent during login.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['refresh_token_dto'] = \
            refresh_token_dto
        return self.refresh_token_endpoint.call_with_http_info(**kwargs)

    def reset_password(
        self,
        reset_password_by_customer_request_dto,
        **kwargs
    ):
        """Change password by customer  # noqa: E501

        Change customer's password using the token provided by the reset password endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.reset_password(reset_password_by_customer_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            reset_password_by_customer_request_dto (ResetPasswordByCustomerRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reset_password_by_customer_request_dto'] = \
            reset_password_by_customer_request_dto
        return self.reset_password_endpoint.call_with_http_info(**kwargs)

    def respond_to_auth_challenge(
        self,
        respond_to_auth_challenge_request_dto,
        **kwargs
    ):
        """Respond to auth challenge  # noqa: E501

        Respond to the auth challenge by customer to get new access token, refresh token after successful login.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.respond_to_auth_challenge(respond_to_auth_challenge_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            respond_to_auth_challenge_request_dto (RespondToAuthChallengeRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RespondToAuthChallengeClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['respond_to_auth_challenge_request_dto'] = \
            respond_to_auth_challenge_request_dto
        return self.respond_to_auth_challenge_endpoint.call_with_http_info(**kwargs)

    def verify_reset_password_token(
        self,
        reset_token,
        **kwargs
    ):
        """Verify a reset password token  # noqa: E501

        Verify the reset password token that is sent by calling the 'forgot password' endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.verify_reset_password_token(reset_token, async_req=True)
        >>> result = thread.get()

        Args:
            reset_token (str): reset password token

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reset_token'] = \
            reset_token
        return self.verify_reset_password_token_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from eis.customers.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from eis.customers.model.account_class import AccountClass
from eis.customers.model.account_policy_class import AccountPolicyClass
from eis.customers.model.authentication_result_class import AuthenticationResultClass
from eis.customers.model.claim_class import ClaimClass
from eis.customers.model.complete_braintree_payment_setup_request_dto import CompleteBraintreePaymentSetupRequestDto
from eis.customers.model.complete_payment_setup_psp_request import CompletePaymentSetupPspRequest
from eis.customers.model.complete_payment_setup_response_class import CompletePaymentSetupResponseClass
from eis.customers.model.complete_stripe_payment_setup_request_dto import CompleteStripePaymentSetupRequestDto
from eis.customers.model.create_account_request_dto import CreateAccountRequestDto
from eis.customers.model.create_bank_account_request_dto import CreateBankAccountRequestDto
from eis.customers.model.create_customer_claim_request_dto import CreateCustomerClaimRequestDto
from eis.customers.model.create_customer_claim_response_class import CreateCustomerClaimResponseClass
from eis.customers.model.create_customer_request_dto import CreateCustomerRequestDto
from eis.customers.model.create_customer_response_class import CreateCustomerResponseClass
from eis.customers.model.create_lead_request_dto import CreateLeadRequestDto
from eis.customers.model.create_lead_response_class import CreateLeadResponseClass
from eis.customers.model.create_payment_method_request_dto import CreatePaymentMethodRequestDto
from eis.customers.model.create_policy_request_dto import CreatePolicyRequestDto
from eis.customers.model.create_presigned_post_response_class import CreatePresignedPostResponseClass
from eis.customers.model.customer_class import CustomerClass
from eis.customers.model.customer_document_class import CustomerDocumentClass
from eis.customers.model.customer_product_class import CustomerProductClass
from eis.customers.model.forgot_password_request_dto import ForgotPasswordRequestDto
from eis.customers.model.get_customer_claim_response_class import GetCustomerClaimResponseClass
from eis.customers.model.get_customer_document_download_url_response_class import GetCustomerDocumentDownloadUrlResponseClass
from eis.customers.model.get_customer_response_class import GetCustomerResponseClass
from eis.customers.model.get_lead_response_class import GetLeadResponseClass
from eis.customers.model.get_policy_response_class import GetPolicyResponseClass
from eis.customers.model.get_product_response_class import GetProductResponseClass
from eis.customers.model.grpc_update_lead_request_dto import GrpcUpdateLeadRequestDto
from eis.customers.model.initiate_auth_request_dto import InitiateAuthRequestDto
from eis.customers.model.initiate_auth_response_class import InitiateAuthResponseClass
from eis.customers.model.initiate_braintree_payment_setup_response_class import InitiateBraintreePaymentSetupResponseClass
from eis.customers.model.initiate_payment_setup_response_class import InitiatePaymentSetupResponseClass
from eis.customers.model.initiate_stripe_payment_setup_response_class import InitiateStripePaymentSetupResponseClass
from eis.customers.model.inline_response200 import InlineResponse200
from eis.customers.model.inline_response503 import InlineResponse503
from eis.customers.model.invite_by_customer_request_dto import InviteByCustomerRequestDto
from eis.customers.model.invite_by_customer_response_class import InviteByCustomerResponseClass
from eis.customers.model.invite_by_tenant_request_dto import InviteByTenantRequestDto
from eis.customers.model.invite_by_tenant_response_class import InviteByTenantResponseClass
from eis.customers.model.invite_class import InviteClass
from eis.customers.model.invoice_class import InvoiceClass
from eis.customers.model.lead_bank_account_class import LeadBankAccountClass
from eis.customers.model.lead_class import LeadClass
from eis.customers.model.list_customer_claims_response_class import ListCustomerClaimsResponseClass
from eis.customers.model.list_documents_response_class import ListDocumentsResponseClass
from eis.customers.model.list_invoices_response_class import ListInvoicesResponseClass
from eis.customers.model.list_leads_response_class import ListLeadsResponseClass
from eis.customers.model.list_policies_response_class import ListPoliciesResponseClass
from eis.customers.model.list_products_response_class import ListProductsResponseClass
from eis.customers.model.policy_class import PolicyClass
from eis.customers.model.policy_object_class import PolicyObjectClass
from eis.customers.model.policy_object_dto import PolicyObjectDto
from eis.customers.model.policy_premium_class import PolicyPremiumClass
from eis.customers.model.policy_premium_item_class import PolicyPremiumItemClass
from eis.customers.model.policy_version_class import PolicyVersionClass
from eis.customers.model.premium_override_dto import PremiumOverrideDto
from eis.customers.model.premium_override_request_class import PremiumOverrideRequestClass
from eis.customers.model.premium_override_request_dto import PremiumOverrideRequestDto
from eis.customers.model.refresh_token_dto import RefreshTokenDto
from eis.customers.model.request_policy_update_request_dto import RequestPolicyUpdateRequestDto
from eis.customers.model.request_policy_update_response_class import RequestPolicyUpdateResponseClass
from eis.customers.model.reset_password_by_customer_request_dto import ResetPasswordByCustomerRequestDto
from eis.customers.model.respond_to_auth_challenge_class import RespondToAuthChallengeClass
from eis.customers.model.respond_to_auth_challenge_request_dto import RespondToAuthChallengeRequestDto
from eis.customers.model.sepa_dto import SepaDto
from eis.customers.model.shared_customer_policy_object_request_dto import SharedCustomerPolicyObjectRequestDto
from eis.customers.model.shared_invoice_item_class import SharedInvoiceItemClass
from eis.customers.model.shared_invoice_status_class import SharedInvoiceStatusClass
from eis.customers.model.terminate_customer_policy_request_dto import TerminateCustomerPolicyRequestDto
from eis.customers.model.terminate_customer_policy_response_class import TerminateCustomerPolicyResponseClass
from eis.customers.model.timeslice_class import TimesliceClass
from eis.customers.model.update_account_request_dto import UpdateAccountRequestDto
from eis.customers.model.update_customer_claim_request_dto import UpdateCustomerClaimRequestDto
from eis.customers.model.update_customer_claim_response_class import UpdateCustomerClaimResponseClass
from eis.customers.model.update_customer_request_dto import UpdateCustomerRequestDto
from eis.customers.model.update_customer_response_class import UpdateCustomerResponseClass
from eis.customers.model.update_lead_request_dto import UpdateLeadRequestDto
from eis.customers.model.update_lead_response_class import UpdateLeadResponseClass
from eis.customers.model.upload_customer_claim_documents_request_dto import UploadCustomerClaimDocumentsRequestDto
from eis.customers.model.upload_customer_policy_documents_request_dto import UploadCustomerPolicyDocumentsRequestDto
from eis.customers.model.uploaded_document_dto import UploadedDocumentDto
from eis.customers.model.verify_customer_invite_response_class import VerifyCustomerInviteResponseClass
from eis.customers.model.withdraw_customer_policy_response_class import WithdrawCustomerPolicyResponseClass



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_bank_account_request_dto import CreateBankAccountRequestDto


class TestCreateBankAccountRequestDto(unittest.TestCase):
    """CreateBankAccountRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateBankAccountRequestDto(self):
        """Test CreateBankAccountRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateBankAccountRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.initiate_stripe_payment_setup_response_class import InitiateStripePaymentSetupResponseClass


class TestInitiateStripePaymentSetupResponseClass(unittest.TestCase):
    """InitiateStripePaymentSetupResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInitiateStripePaymentSetupResponseClass(self):
        """Test InitiateStripePaymentSetupResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InitiateStripePaymentSetupResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.policy_object_class import PolicyObjectClass
from eis.customers.model.policy_premium_class import PolicyPremiumClass
globals()['PolicyObjectClass'] = PolicyObjectClass
globals()['PolicyPremiumClass'] = PolicyPremiumClass
from eis.customers.model.timeslice_class import TimesliceClass


class TestTimesliceClass(unittest.TestCase):
    """TimesliceClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTimesliceClass(self):
        """Test TimesliceClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TimesliceClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.customer_product_class import CustomerProductClass
globals()['CustomerProductClass'] = CustomerProductClass
from eis.customers.model.list_products_response_class import ListProductsResponseClass


class TestListProductsResponseClass(unittest.TestCase):
    """ListProductsResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListProductsResponseClass(self):
        """Test ListProductsResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListProductsResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.policies_api import PoliciesApi  # noqa: E501


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self):
        self.api = PoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer_policy_data_by_date(self):
        """Test case for get_customer_policy_data_by_date

        Get current version details  # noqa: E501
        """
        pass

    def test_get_policy(self):
        """Test case for get_policy

        Get policy details  # noqa: E501
        """
        pass

    def test_list_policies(self):
        """Test case for list_policies

        List policies  # noqa: E501
        """
        pass

    def test_request_policy_update(self):
        """Test case for request_policy_update

        Request policy update  # noqa: E501
        """
        pass

    def test_terminate_customer_policy(self):
        """Test case for terminate_customer_policy

        Terminate a policy  # noqa: E501
        """
        pass

    def test_upload_customer_policy_documents(self):
        """Test case for upload_customer_policy_documents

        Upload policy documents  # noqa: E501
        """
        pass

    def test_withdraw_customer_policy(self):
        """Test case for withdraw_customer_policy

        Withdraw the policy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.leads_api import LeadsApi  # noqa: E501


class TestLeadsApi(unittest.TestCase):
    """LeadsApi unit test stubs"""

    def setUp(self):
        self.api = LeadsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_lead(self):
        """Test case for create_lead

        Create the lead  # noqa: E501
        """
        pass

    def test_get_lead(self):
        """Test case for get_lead

        Retrieve the lead  # noqa: E501
        """
        pass

    def test_list_leads(self):
        """Test case for list_leads

        List leads  # noqa: E501
        """
        pass

    def test_update_lead(self):
        """Test case for update_lead

        Update the lead  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from eis.customers.api.authentication_api import AuthenticationApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from eis.customers.api.authentication_api import AuthenticationApi
from eis.customers.api.claims_api import ClaimsApi
from eis.customers.api.customers_api import CustomersApi
from eis.customers.api.documents_api import DocumentsApi
from eis.customers.api.invites_api import InvitesApi
from eis.customers.api.invoices_api import InvoicesApi
from eis.customers.api.leads_api import LeadsApi
from eis.customers.api.payments_api import PaymentsApi
from eis.customers.api.policies_api import PoliciesApi
from eis.customers.api.products_api import ProductsApi
from eis.customers.api.default_api import DefaultApi



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_bank_account_request_dto import CreateBankAccountRequestDto
from eis.customers.model.create_payment_method_request_dto import CreatePaymentMethodRequestDto
from eis.customers.model.policy_object_dto import PolicyObjectDto
from eis.customers.model.premium_override_request_dto import PremiumOverrideRequestDto
from eis.customers.model.uploaded_document_dto import UploadedDocumentDto
globals()['CreateBankAccountRequestDto'] = CreateBankAccountRequestDto
globals()['CreatePaymentMethodRequestDto'] = CreatePaymentMethodRequestDto
globals()['PolicyObjectDto'] = PolicyObjectDto
globals()['PremiumOverrideRequestDto'] = PremiumOverrideRequestDto
globals()['UploadedDocumentDto'] = UploadedDocumentDto
from eis.customers.model.create_lead_request_dto import CreateLeadRequestDto


class TestCreateLeadRequestDto(unittest.TestCase):
    """CreateLeadRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateLeadRequestDto(self):
        """Test CreateLeadRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateLeadRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.documents_api import DocumentsApi  # noqa: E501


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer_document_download_url(self):
        """Test case for get_customer_document_download_url

        Get a download url for document  # noqa: E501
        """
        pass

    def test_list_documents(self):
        """Test case for list_documents

        List documents of a customer  # noqa: E501
        """
        pass

    def test_upload_account_documents(self):
        """Test case for upload_account_documents

        Upload account documents  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.create_customer_claim_request_dto import CreateCustomerClaimRequestDto
from eis.customers.model.create_customer_claim_response_class import CreateCustomerClaimResponseClass
from eis.customers.model.create_presigned_post_response_class import CreatePresignedPostResponseClass
from eis.customers.model.get_customer_claim_response_class import GetCustomerClaimResponseClass
from eis.customers.model.list_customer_claims_response_class import ListCustomerClaimsResponseClass
from eis.customers.model.update_customer_claim_request_dto import UpdateCustomerClaimRequestDto
from eis.customers.model.update_customer_claim_response_class import UpdateCustomerClaimResponseClass
from eis.customers.model.upload_customer_claim_documents_request_dto import UploadCustomerClaimDocumentsRequestDto


class ClaimsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_customer_claim_endpoint = _Endpoint(
            settings={
                'response_type': (CreateCustomerClaimResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/claims',
                'operation_id': 'create_customer_claim',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'create_customer_claim_request_dto',
                    'authorization',
                    'authorization2',
                ],
                'required': [
                    'customer_code',
                    'create_customer_claim_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'create_customer_claim_request_dto':
                        (CreateCustomerClaimRequestDto,),
                    'authorization':
                        (str,),
                    'authorization2':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                    'authorization2': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'create_customer_claim_request_dto': 'body',
                    'authorization': 'header',
                    'authorization2': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_customer_claim_endpoint = _Endpoint(
            settings={
                'response_type': (GetCustomerClaimResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/claims/{claimCode}',
                'operation_id': 'get_customer_claim',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'claim_code',
                    'authorization',
                    'authorization2',
                ],
                'required': [
                    'customer_code',
                    'claim_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'claim_code':
                        (str,),
                    'authorization':
                        (str,),
                    'authorization2':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'claim_code': 'claimCode',
                    'authorization': 'Authorization',
                    'authorization2': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'claim_code': 'path',
                    'authorization': 'header',
                    'authorization2': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_customer_claims_endpoint = _Endpoint(
            settings={
                'response_type': (ListCustomerClaimsResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/claims',
                'operation_id': 'list_customer_claims',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'authorization',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'authorization2',
                ],
                'required': [
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'authorization':
                        (str,),
                    'page_size':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'page_token':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'filter':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'search':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'order':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'expand':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'authorization2':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'authorization2': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'authorization': 'header',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'authorization2': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_customer_claim_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateCustomerClaimResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/claims/{claimCode}',
                'operation_id': 'update_customer_claim',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'claim_code',
                    'update_customer_claim_request_dto',
                    'authorization',
                    'authorization2',
                ],
                'required': [
                    'customer_code',
                    'claim_code',
                    'update_customer_claim_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'claim_code':
                        (str,),
                    'update_customer_claim_request_dto':
                        (UpdateCustomerClaimRequestDto,),
                    'authorization':
                        (str,),
                    'authorization2':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'claim_code': 'claimCode',
                    'authorization': 'Authorization',
                    'authorization2': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'claim_code': 'path',
                    'update_customer_claim_request_dto': 'body',
                    'authorization': 'header',
                    'authorization2': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.upload_customer_claim_documents_endpoint = _Endpoint(
            settings={
                'response_type': (CreatePresignedPostResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/claims/{claimCode}/documents',
                'operation_id': 'upload_customer_claim_documents',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'claim_code',
                    'upload_customer_claim_documents_request_dto',
                    'authorization',
                    'authorization2',
                ],
                'required': [
                    'customer_code',
                    'claim_code',
                    'upload_customer_claim_documents_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'claim_code':
                        (str,),
                    'upload_customer_claim_documents_request_dto':
                        (UploadCustomerClaimDocumentsRequestDto,),
                    'authorization':
                        (str,),
                    'authorization2':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'claim_code': 'claimCode',
                    'authorization': 'Authorization',
                    'authorization2': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'claim_code': 'path',
                    'upload_customer_claim_documents_request_dto': 'body',
                    'authorization': 'header',
                    'authorization2': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_customer_claim(
        self,
        customer_code,
        create_customer_claim_request_dto,
        **kwargs
    ):
        """Create a new claim  # noqa: E501

        Create a new claim for customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_customer_claim(customer_code, create_customer_claim_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            create_customer_claim_request_dto (CreateCustomerClaimRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            authorization2 (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateCustomerClaimResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['create_customer_claim_request_dto'] = \
            create_customer_claim_request_dto
        return self.create_customer_claim_endpoint.call_with_http_info(**kwargs)

    def get_customer_claim(
        self,
        customer_code,
        claim_code,
        **kwargs
    ):
        """Get claim  # noqa: E501

        Get claim for customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_customer_claim(customer_code, claim_code, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            claim_code (str): The claim code to identify a claim.

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            authorization2 (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetCustomerClaimResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['claim_code'] = \
            claim_code
        return self.get_customer_claim_endpoint.call_with_http_info(**kwargs)

    def list_customer_claims(
        self,
        customer_code,
        **kwargs
    ):
        """List claims  # noqa: E501

        List claims by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_customer_claims(customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            page_size (bool, date, datetime, dict, float, int, list, str, none_type): A limit on the number of objects to be returned.     Limit ranges between 1 and 100. Default: 10.. [optional]
            page_token (bool, date, datetime, dict, float, int, list, str, none_type): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1,     your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (bool, date, datetime, dict, float, int, list, str, none_type): Filter the response by one or multiple fields.     In general, fetching filtered responses will conserve bandwidth and reduce response time.. [optional]
            search (bool, date, datetime, dict, float, int, list, str, none_type): Search the list by any field. For instance, if you want to search by code     add code=xxx in order to fetch the result.. [optional]
            order (bool, date, datetime, dict, float, int, list, str, none_type): The order parameter determines how the results should be sorted according to a specified field.     It functions similarly to an SQL ORDER BY.     Sorting can be performed in either ascending (ASC) or descending (DESC) order.     Default: ASC.. [optional]
            expand (bool, date, datetime, dict, float, int, list, str, none_type): Use this parameter to fetch additional information about the list items.     The expand query parameter increases the set of fields that appear in the response in     addition to the default ones.     Expanding resources can reduce the number of API calls required to accomplish a task.     However, use this with parsimony as some expanded fields can drastically increase payload size.. [optional]
            authorization2 (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListCustomerClaimsResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        return self.list_customer_claims_endpoint.call_with_http_info(**kwargs)

    def update_customer_claim(
        self,
        customer_code,
        claim_code,
        update_customer_claim_request_dto,
        **kwargs
    ):
        """Update claim  # noqa: E501

        Update claim for customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_customer_claim(customer_code, claim_code, update_customer_claim_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            claim_code (str): The claim code to identify a claim.
            update_customer_claim_request_dto (UpdateCustomerClaimRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            authorization2 (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            UpdateCustomerClaimResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['claim_code'] = \
            claim_code
        kwargs['update_customer_claim_request_dto'] = \
            update_customer_claim_request_dto
        return self.update_customer_claim_endpoint.call_with_http_info(**kwargs)

    def upload_customer_claim_documents(
        self,
        customer_code,
        claim_code,
        upload_customer_claim_documents_request_dto,
        **kwargs
    ):
        """Upload claim documents  # noqa: E501

        API to upload and attach documents to a claim.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_customer_claim_documents(customer_code, claim_code, upload_customer_claim_documents_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str):
            claim_code (str): The claim code to identify a claim.
            upload_customer_claim_documents_request_dto (UploadCustomerClaimDocumentsRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            authorization2 (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreatePresignedPostResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['claim_code'] = \
            claim_code
        kwargs['upload_customer_claim_documents_request_dto'] = \
            upload_customer_claim_documents_request_dto
        return self.upload_customer_claim_documents_endpoint.call_with_http_info(**kwargs)




"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.create_presigned_post_response_class import CreatePresignedPostResponseClass
from eis.customers.model.get_policy_response_class import GetPolicyResponseClass
from eis.customers.model.list_policies_response_class import ListPoliciesResponseClass
from eis.customers.model.request_policy_update_request_dto import RequestPolicyUpdateRequestDto
from eis.customers.model.request_policy_update_response_class import RequestPolicyUpdateResponseClass
from eis.customers.model.terminate_customer_policy_request_dto import TerminateCustomerPolicyRequestDto
from eis.customers.model.terminate_customer_policy_response_class import TerminateCustomerPolicyResponseClass
from eis.customers.model.upload_customer_policy_documents_request_dto import UploadCustomerPolicyDocumentsRequestDto
from eis.customers.model.withdraw_customer_policy_response_class import WithdrawCustomerPolicyResponseClass


class PoliciesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_customer_policy_data_by_date_endpoint = _Endpoint(
            settings={
                'response_type': (GetPolicyResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}/current-version',
                'operation_id': 'get_customer_policy_data_by_date',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'policy_code',
                    'customer_code',
                    'timeslice_date',
                    'authorization',
                ],
                'required': [
                    'policy_code',
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'policy_code':
                        (str,),
                    'customer_code':
                        (str,),
                    'timeslice_date':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'policy_code': 'policyCode',
                    'customer_code': 'customerCode',
                    'timeslice_date': 'timesliceDate',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'policy_code': 'path',
                    'customer_code': 'path',
                    'timeslice_date': 'query',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_policy_endpoint = _Endpoint(
            settings={
                'response_type': (GetPolicyResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}',
                'operation_id': 'get_policy',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'policy_code',
                    'customer_code',
                    'expand',
                    'authorization',
                ],
                'required': [
                    'policy_code',
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'policy_code':
                        (str,),
                    'customer_code':
                        (str,),
                    'expand':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'policy_code': 'policyCode',
                    'customer_code': 'customerCode',
                    'expand': 'expand',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'policy_code': 'path',
                    'customer_code': 'path',
                    'expand': 'query',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_policies_endpoint = _Endpoint(
            settings={
                'response_type': (ListPoliciesResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies',
                'operation_id': 'list_policies',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'authorization',
                ],
                'required': [
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'page_size':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'page_token':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'filter':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'search':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'order':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'expand':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.request_policy_update_endpoint = _Endpoint(
            settings={
                'response_type': (RequestPolicyUpdateResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}/request-update',
                'operation_id': 'request_policy_update',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'policy_code',
                    'customer_code',
                    'request_policy_update_request_dto',
                    'authorization',
                ],
                'required': [
                    'policy_code',
                    'customer_code',
                    'request_policy_update_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'policy_code':
                        (str,),
                    'customer_code':
                        (str,),
                    'request_policy_update_request_dto':
                        (RequestPolicyUpdateRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'policy_code': 'policyCode',
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'policy_code': 'path',
                    'customer_code': 'path',
                    'request_policy_update_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.terminate_customer_policy_endpoint = _Endpoint(
            settings={
                'response_type': (TerminateCustomerPolicyResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}/terminate',
                'operation_id': 'terminate_customer_policy',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'policy_code',
                    'customer_code',
                    'terminate_customer_policy_request_dto',
                    'authorization',
                ],
                'required': [
                    'policy_code',
                    'customer_code',
                    'terminate_customer_policy_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'policy_code':
                        (str,),
                    'customer_code':
                        (str,),
                    'terminate_customer_policy_request_dto':
                        (TerminateCustomerPolicyRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'policy_code': 'policyCode',
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'policy_code': 'path',
                    'customer_code': 'path',
                    'terminate_customer_policy_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.upload_customer_policy_documents_endpoint = _Endpoint(
            settings={
                'response_type': (CreatePresignedPostResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}/documents',
                'operation_id': 'upload_customer_policy_documents',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'policy_code',
                    'upload_customer_policy_documents_request_dto',
                ],
                'required': [
                    'customer_code',
                    'policy_code',
                    'upload_customer_policy_documents_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'policy_code':
                        (str,),
                    'upload_customer_policy_documents_request_dto':
                        (UploadCustomerPolicyDocumentsRequestDto,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'policy_code': 'policyCode',
                },
                'location_map': {
                    'customer_code': 'path',
                    'policy_code': 'path',
                    'upload_customer_policy_documents_request_dto': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.withdraw_customer_policy_endpoint = _Endpoint(
            settings={
                'response_type': (WithdrawCustomerPolicyResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/policies/{policyCode}/withdraw',
                'operation_id': 'withdraw_customer_policy',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'policy_code',
                    'customer_code',
                    'authorization',
                ],
                'required': [
                    'policy_code',
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'policy_code':
                        (str,),
                    'customer_code':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'policy_code': 'policyCode',
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'policy_code': 'path',
                    'customer_code': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_customer_policy_data_by_date(
        self,
        policy_code,
        customer_code,
        **kwargs
    ):
        """Get current version details  # noqa: E501

        Get detailed policy that belongs to a customer;        the details are filtered to return only the current       version and the interval timeline that the provided date is included.       If the date is not specified, the system will return the whole timeline.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_customer_policy_data_by_date(policy_code, customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            policy_code (str): The policy code.
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            timeslice_date (str): This date is used to filter data of the policy, to select the appropriate timeslice.       If no date is specified, the system returns all the timeslices.. [optional]
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetPolicyResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['policy_code'] = \
            policy_code
        kwargs['customer_code'] = \
            customer_code
        return self.get_customer_policy_data_by_date_endpoint.call_with_http_info(**kwargs)

    def get_policy(
        self,
        policy_code,
        customer_code,
        **kwargs
    ):
        """Get policy details  # noqa: E501

        Get detailed policy that belongs to a customer; the details can be expanded using expand query parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_policy(policy_code, customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            policy_code (str): The policy code.
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            expand (str): Fields to expand response by - [versions, premiumItems]. [optional]
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetPolicyResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['policy_code'] = \
            policy_code
        kwargs['customer_code'] = \
            customer_code
        return self.get_policy_endpoint.call_with_http_info(**kwargs)

    def list_policies(
        self,
        customer_code,
        **kwargs
    ):
        """List policies  # noqa: E501

        List all the policies that belong to a customer, the policies can be filtered by policy code, policy number.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_policies(customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            page_size (bool, date, datetime, dict, float, int, list, str, none_type): A limit on the number of objects to be returned.     Limit ranges between 1 and 100. Default: 10.. [optional]
            page_token (bool, date, datetime, dict, float, int, list, str, none_type): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1,     your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (bool, date, datetime, dict, float, int, list, str, none_type): Filter the response by one or multiple fields.     In general, fetching filtered responses will conserve bandwidth and reduce response time.. [optional]
            search (bool, date, datetime, dict, float, int, list, str, none_type): Search the list by any field. For instance, if you want to search by code     add code=xxx in order to fetch the result.. [optional]
            order (bool, date, datetime, dict, float, int, list, str, none_type): The order parameter determines how the results should be sorted according to a specified field.     It functions similarly to an SQL ORDER BY.     Sorting can be performed in either ascending (ASC) or descending (DESC) order.     Default: ASC.. [optional]
            expand (bool, date, datetime, dict, float, int, list, str, none_type): Use this parameter to fetch additional information about the list items.     The expand query parameter increases the set of fields that appear in the response in     addition to the default ones.     Expanding resources can reduce the number of API calls required to accomplish a task.     However, use this with parsimony as some expanded fields can drastically increase payload size.. [optional]
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListPoliciesResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        return self.list_policies_endpoint.call_with_http_info(**kwargs)

    def request_policy_update(
        self,
        policy_code,
        customer_code,
        request_policy_update_request_dto,
        **kwargs
    ):
        """Request policy update  # noqa: E501

        Request to update an existing policy by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.request_policy_update(policy_code, customer_code, request_policy_update_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            policy_code (str): The code of the policy that the customer wants to update.
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            request_policy_update_request_dto (RequestPolicyUpdateRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RequestPolicyUpdateResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['policy_code'] = \
            policy_code
        kwargs['customer_code'] = \
            customer_code
        kwargs['request_policy_update_request_dto'] = \
            request_policy_update_request_dto
        return self.request_policy_update_endpoint.call_with_http_info(**kwargs)

    def terminate_customer_policy(
        self,
        policy_code,
        customer_code,
        terminate_customer_policy_request_dto,
        **kwargs
    ):
        """Terminate a policy  # noqa: E501

        Request to terminate an existing policy by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.terminate_customer_policy(policy_code, customer_code, terminate_customer_policy_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            policy_code (str): The code of the policy that the customer wants to terminate.
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            terminate_customer_policy_request_dto (TerminateCustomerPolicyRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            TerminateCustomerPolicyResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['policy_code'] = \
            policy_code
        kwargs['customer_code'] = \
            customer_code
        kwargs['terminate_customer_policy_request_dto'] = \
            terminate_customer_policy_request_dto
        return self.terminate_customer_policy_endpoint.call_with_http_info(**kwargs)

    def upload_customer_policy_documents(
        self,
        customer_code,
        policy_code,
        upload_customer_policy_documents_request_dto,
        **kwargs
    ):
        """Upload policy documents  # noqa: E501

        API to upload and attach documents to a policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_customer_policy_documents(customer_code, policy_code, upload_customer_policy_documents_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str):
            policy_code (str): The policy code to identify a policy.
            upload_customer_policy_documents_request_dto (UploadCustomerPolicyDocumentsRequestDto):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreatePresignedPostResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['policy_code'] = \
            policy_code
        kwargs['upload_customer_policy_documents_request_dto'] = \
            upload_customer_policy_documents_request_dto
        return self.upload_customer_policy_documents_endpoint.call_with_http_info(**kwargs)

    def withdraw_customer_policy(
        self,
        policy_code,
        customer_code,
        **kwargs
    ):
        """Withdraw the policy  # noqa: E501

        Withdraw policy by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.withdraw_customer_policy(policy_code, customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            policy_code (str): The code of the policy that the customer wants to withdraw.
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            WithdrawCustomerPolicyResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['policy_code'] = \
            policy_code
        kwargs['customer_code'] = \
            customer_code
        return self.withdraw_customer_policy_endpoint.call_with_http_info(**kwargs)




"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.payments_api import PaymentsApi  # noqa: E501


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self):
        self.api = PaymentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_payment_setup(self):
        """Test case for complete_payment_setup

        Request payment setup complete  # noqa: E501
        """
        pass

    def test_initiate_payment_setup(self):
        """Test case for initiate_payment_setup

        Request payment setup initiation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.invites_api import InvitesApi  # noqa: E501


class TestInvitesApi(unittest.TestCase):
    """InvitesApi unit test stubs"""

    def setUp(self):
        self.api = InvitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer(self):
        """Test case for create_customer

        Register a customer after invite  # noqa: E501
        """
        pass

    def test_invite_by_customer(self):
        """Test case for invite_by_customer

        Invite a customer by self  # noqa: E501
        """
        pass

    def test_invite_by_tenant(self):
        """Test case for invite_by_tenant

        Invite a customer by tenant  # noqa: E501
        """
        pass

    def test_verify_invite(self):
        """Test case for verify_invite

        Verify customer's invite token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
